#' Data from Home Owner's Survey on Total Number of Books 
#'
#' Data from home owner's survey on total number of books 
#' @name books
#' @docType data
#' @format Data frame with the following 6 variables: 
#' \describe{
#'   \item{shelf}{shelf number}
#'   \item{number}{number of the book selected}
#'   \item{purchase}{purchase cost of the book}
#'   \item{replace}{replacement cost of book}
#' }
#' @note Used in Exercise 6 of Chapter 5.
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   439. 
"books"